teedoc
===========

[中文 README](./README_ZH.md)

[![License](https://img.shields.io/github/license/teedoc/teedoc?color=red)](./LICENSE) [![PyPI](https://img.shields.io/pypi/v/teedoc)](https://pypi.org/project/teedoc/#history) ![PyPI - Downloads](https://img.shields.io/pypi/dm/teedoc?color=brightgreen) ![PyPI - Downloads](https://img.shields.io/pypi/dw/teedoc?color=brightgreen) [![GitHub Repo stars](https://img.shields.io/github/stars/teedoc/teedoc?style=social)](https://github.com/teedoc/teedoc)

<img src="https://teedoc.github.io/static/image/logo.png" height=64/> 

Official site: [teedoc.neucrack.com](https://teedoc.neucrack.com) or [teedoc.github.io](https://teedoc.github.io/)

documentation generate tool from markdown and jupyter notebook to html

![](./assets/images/teedoc_screenshot_0.png)

`teedoc` can be used in the following scenarios:
* Build a document website, and it is best to support multiple documents and custom pages
* Build a `WiKi` website
* Build personal or corporate knowledge base
* Build personal or corporate website


## Features

- [x] Easy to use, cross platform, only need `Python3`
- [x] Easy to deploy, only copy generated staitc HTML files to your server or other host
- [x] Easy to write, markdown support
- [x] Jupyter notebook support
- [x] Multiple docs support
- [x] Plugin support
- [x] Multiple theme support(support by plugin)
- [x] Control the style accurate to the page through css (implemented by customizing the id and class of each page)
- [x] Multi-level directory support
- [x] Multiple language support(manually translate)
- [ ] Multiple language support(auto translate)
- [x] Multiple version support
- [x] Search support
- [x] SEO friendly
- [x] Real-time preview file changes
- [x] Multiple thread support, faster build speed
- [x] Blog support


## Get Started

Visit official site: [teedoc.github.io](https://teedoc.github.io/) or [teedoc.gitee.io](https://teedoc.gitee.io/)

